import { isScriptableUrl } from 'webext-content-scripts';
import { isBackground } from 'webext-detect-page';
import { SimpleEventTarget } from './simple-event-target';
if (!isBackground()) {
    throw new Error('This module is only allowed in a background script');
}
export const possiblyActiveTabs = new Map();
const newActiveTabs = new SimpleEventTarget();
const browserAction = chrome.action ?? chrome.browserAction;
function trackIfScriptable({ url, id }) {
    if (!id || !url || !isScriptableUrl(url)) {
        return;
    }
    const { origin } = new URL(url);
    if (possiblyActiveTabs.get(id) !== origin) {
        possiblyActiveTabs.set(id, origin);
        newActiveTabs.emit({ id, origin });
    }
}
function altListener(_, tab) {
    if (tab) {
        trackIfScriptable(tab);
    }
}
function removalListener(tabId) {
    possiblyActiveTabs.delete(tabId);
}
export function startActiveTabTracking() {
    browserAction?.onClicked.addListener(trackIfScriptable);
    chrome.contextMenus?.onClicked.addListener(altListener);
    chrome.commands?.onCommand.addListener(altListener);
    chrome.tabs.onRemoved.addListener(removalListener);
}
export function stopActiveTabTracking() {
    browserAction?.onClicked.removeListener(trackIfScriptable);
    chrome.contextMenus?.onClicked.removeListener(altListener);
    chrome.commands?.onCommand.removeListener(altListener);
    chrome.tabs.onRemoved.removeListener(removalListener);
    possiblyActiveTabs.clear();
}
export function onActiveTab(callback) {
    startActiveTabTracking();
    newActiveTabs.add(callback);
}
